@@ -12,6 +12,10 @@
 #' 
 plot.cSEMPredict <- function(x, ...) {
   
+  if(!inherits(x, "cSEMPredict")) {
+    stop2("x must be of class `cSEMPredict`.")
+  }
+  
   ## Install ggplot2 if not already installed
   if (!requireNamespace("ggplot2", quietly = TRUE)) {
     stop2(
