@@ -6,7 +6,7 @@ model <- "
 eta2 ~ eta1
 eta3 ~ eta1 + eta2
 
-# Measurement
+# Measurement model
 eta1 =~ y11 + y12 + y13
 eta2 =~ y21 + y22 + y23
 eta3 =~ y31 + y32 + y33
@@ -18,4 +18,4 @@ eta3 =~ y31 + y32 + y33
 runif(1)
 
 system.time(csem(threecommonfactors, model, .resample_method = "bootstrap", .R = 1000,
-                 .eval_plan = "multiprocess"))
+                 .eval_plan = "multisession"))
